-- WoWRosterExport : WRE
local debugg = true;
local WREFrame = CreateFrame('Frame', 'WREFrame', UIParent);
local WREExportBox = CreateFrame('EditBox', 'WREExportBox', UIParent);

-- Register used events
WREFrame:RegisterEvent("PLAYER_ENTERING_WORLD");
WREFrame:RegisterEvent("CALENDAR_OPEN_EVENT");
WREFrame:RegisterEvent("CALENDAR_CLOSE_EVENT");

function WREFrame:PLAYER_ENTERING_WORLD()

    if (not IsAddOnLoaded("Blizzard_Calendar")) then
        if debugg then print("Loading Calendar Addon") end
        UIParentLoadAddOn("Blizzard_Calendar");
    end

    -- Generate main frame
    WREFrame:SetFrameStrata('DIALOG');
    WREFrame:SetToplevel(true);
    WREFrame:EnableMouse(true);
    WREFrame:SetClampedToScreen(true);
    WREFrame:SetBackdrop {
        bgFile = 'Interface\\DialogFrame\\UI-DialogBox-Background',
        edgeFile = 'Interface\\DialogFrame\\UI-DialogBox-Border',
        tile = true,
        insets = { left = 11, right = 12, top = 12, bottom = 11 },
        tileSize = 32,
        edgeSize = 32,
    }
    WREFrame:SetPoint('TOPLEFT', CalendarViewEventFrame, 'BOTTOMLEFT', 0, 0);
    WREFrame:SetWidth(CalendarViewEventFrame:GetWidth());
    WREFrame:SetHeight(100);
    WREFrame:Hide();

    local title = WREFrame:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
    title:SetPoint("TOPLEFT", 16, -16);
    title:SetText("Export event members");
    WREFrame.Title = title;

    local exportButton = CreateFrame('Button', 'WREExportButton', WREFrame, "OptionsButtonTemplate");
    exportButton:SetPoint("TOPRIGHT", -12, -16);
    exportButton:SetWidth(80);
    exportButton:SetHeight(22);
    exportButton:SetText("Export");
    exportButton:SetScript('OnClick', WREFrame_Export)
    exportButton:Show();

    local closeButton = CreateFrame('Button', 'WRECloseButton', WREFrame, "OptionsButtonTemplate");
    closeButton:SetPoint("TOPLEFT", WREFrame:GetWidth() - 15, 5);
    closeButton:SetWidth(22);
    closeButton:SetHeight(22);
    closeButton:SetText("X");
    closeButton:SetScript('OnClick', function(self)
        WREFrame:Hide();
    end)
    closeButton:Show();

    WREExportBox:SetMultiLine(true);
    WREExportBox:SetAutoFocus(true);
    WREExportBox:EnableMouse(true);
    WREExportBox:SetMaxLetters(99999);
    WREExportBox:SetFont('Fonts\\ARIALN.ttf', 13, 'THINOUTLINE');
    WREExportBox:SetWidth(CalendarViewEventFrame:GetWidth() - 10);
    WREExportBox:SetHeight(80);
    WREExportBox:SetScript("OnEscapePressed", function(self)
        WREFrame:Hide()
    end)

    local WREScrollFrame = CreateFrame('ScrollFrame', 'WREExportScroll', WREFrame, 'UIPanelScrollFrameTemplate')
    WREScrollFrame:SetPoint('TOPLEFT', WREFrame, 'TOPLEFT', 10, -40)
    WREScrollFrame:SetPoint('BOTTOMRIGHT', WREFrame, 'BOTTOMRIGHT', -10, 10)
    WREScrollFrame:SetScrollChild(WREExportBox)

    if debugg then print("WoWRosterExport loaded") end
end

function WREFrame_Export()
    if debugg then print("WRE : generating export") end
    WREExportBox:Show();
    -- Call calendar
    monthOffset, day, index = CalendarContextGetEventIndex()
    CalendarOpenEvent(monthOffset, day, index);
    title, description, creator, eventType, repeatOption, maxSize, textureIndex, weekday,
    month, day, year, hour, minute, lockoutWeekday, lockoutMonth, lockoutDay, lockoutYear,
    lockoutHour, lockoutMinute, locked, autoApprove, pendingInvite, inviteStatus, inviteType,
    calendarType = CalendarGetEventInfo();
    local typeStr = "";
    if eventType == 1 then
        typeStr = "Raid";
    elseif eventType == 2 then
        typeStr = "Dungeon";
    elseif eventType == 3 then
        typeStr = "PvP";
    else
        typeStr = "Other";
    end
    local numInvites = CalendarEventGetNumInvites()
    if debugg then print("Member count : " .. numInvites) end
    if debugg then print("Event type : " .. eventType) end
    local exportText = "ROSTER_EXPORT#" .. typeStr .. "#" .. title .. "\n";
    for invitee = 1, numInvites do
        name, level, className, classFilename, inviteStatus, modStatus = CalendarEventGetInvite(invitee);
        if inviteStatus == 4 or inviteStatus == 7 then
            exportText = exportText .. name .. ";";
        end
    end
    WREExportBox:SetText(exportText);
    WREExportBox:HighlightText(0);

    if debugg then print("WRE : Export done") end
end

function WREFrame:CALENDAR_OPEN_EVENT()
    if debugg then print("CALENDAR_OPEN_EVENT") end
    WREExportBox:SetText("");
    WREExportBox:Hide();
    WREFrame:Show();
end

function WREFrame:CALENDAR_CLOSE_EVENT()
    if debugg then print("CALENDAR_CLOSE_EVENT") end
    WREFrame:Hide();
end

-- set handlers for frame events
WREFrame:SetScript("OnEvent", function(self, event, ...)
    if self[event] then
        self[event](self, ...)
    end
end)